@@ -19,8 +19,14 @@
  ***************************************************************************/
 
 #include "AppPackageKitResource.h"
+#ifdef NEWAPPSTREAM
+#include <AppStreamQt/icon.h>
+#include <AppStreamQt/screenshot.h>
+#include <AppStreamQt/image.h>
+#else
 #include <AppstreamQt/screenshot.h>
 #include <AppstreamQt/image.h>
+#endif
 // #include <AppstreamQt/release.h>
 #include <KLocalizedString>
 #include <KToolInvocation>
@@ -52,7 +58,23 @@ QString AppPackageKitResource::longDescription()
 QVariant AppPackageKitResource::icon() const
 {
     QIcon ret;
-
+#ifdef NEWAPPSTREAM
+    const auto icons = m_appdata.icons();
+    if (icons.isEmpty()) {
+        ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
+    } else foreach(const AppStream::Icon &icon, icons) {
+        switch(icon.kind()) {
+            case AppStream::Icon::KindLocal:
+                ret.addFile(icon.url().toLocalFile(), icon.size());
+                break;
+            case AppStream::Icon::KindCached:
+                ret.addFile(icon.url().toLocalFile(), icon.size());
+                break;
+            default:
+                break;
+        }
+    }
+#else
     const auto icons = m_appdata.iconUrls();
     if (icons.isEmpty())
         return m_appdata.name();
@@ -66,7 +88,7 @@ QVariant AppPackageKitResource::icon() const
     if (ret.isNull()) {
         ret = QIcon::fromTheme(QStringLiteral("package-x-generic"));
     }
-
+#endif
     return ret;
 }
 
@@ -105,7 +127,11 @@ QString AppPackageKitResource::appstreamId() const
 
 QUrl AppPackageKitResource::homepage()
 {
+#ifdef NEWAPPSTREAM
+    return m_appdata.url(Appstream::Component::UrlKindHomepage);
+#else
     return m_appdata.urls().value(Appstream::Component::UrlKindHomepage);
+#endif
 }
 
 bool AppPackageKitResource::isTechnical() const
@@ -150,13 +176,20 @@ static QUrl screenshot(const Appstream::Component& comp, Appstream::Image::Kind
 
 QUrl AppPackageKitResource::screenshotUrl()
 {
+#ifdef NEWAPPSTREAM
+    return screenshot(m_appdata, Appstream::Image::KindSource);
+#else
     return screenshot(m_appdata, Appstream::Image::Plain);
-
+#endif
 }
 
 QUrl AppPackageKitResource::thumbnailUrl()
 {
-    return screenshot(m_appdata, Appstream::Image::Thumbnail);
+#ifdef NEWAPPSTREAM
+    return screenshot(m_appdata, Appstream::Image::KindThumbnail);
+#else
+     return screenshot(m_appdata, Appstream::Image::Thumbnail);
+#endif
 }
 
 void AppPackageKitResource::fetchScreenshots()
@@ -164,8 +197,13 @@ void AppPackageKitResource::fetchScreenshots()
     QList<QUrl> thumbnails, screenshots;
 
     Q_FOREACH (const Appstream::Screenshot &s, m_appdata.screenshots()) {
-        const QUrl thumbnail = imageOfKind(s.images(), Appstream::Image::Thumbnail);
-        const QUrl plain = imageOfKind(s.images(), Appstream::Image::Plain);
+#ifdef NEWAPPSTREAM
+        const QUrl thumbnail = imageOfKind(s.images(), Appstream::Image::KindThumbnail);
+        const QUrl plain = imageOfKind(s.images(), Appstream::Image::KindSource);
+#else
+         const QUrl thumbnail = imageOfKind(s.images(), Appstream::Image::Thumbnail);
+         const QUrl plain = imageOfKind(s.images(), Appstream::Image::Plain);
+#endif
         if (plain.isEmpty())
             qWarning() << "invalid screenshot for" << name();
 
@@ -183,11 +221,15 @@ bool AppPackageKitResource::canExecute() const
 
 QStringList AppPackageKitResource::findProvides(Appstream::Provides::Kind kind) const
 {
+#ifdef NEWAPPSTREAM
+    return m_appdata.provided(kind).items();
+#else
     QStringList ret;
     Q_FOREACH (Appstream::Provides p, m_appdata.provides())
         if (p.kind() == kind)
             ret += p.value();
     return ret;
+#endif
 }
 
 QStringList AppPackageKitResource::allPackageNames() const
