@@ -29,7 +29,18 @@
 #include <QTimer>
 #include <QSet>
 #include <PackageKit/Transaction>
+
+#ifdef NEWAPPSTREAM
+#include <AppStreamQt/pool.h>
+#include <AppStreamQt/provided.h>
+namespace AppStream {
+    typedef Provided Provides;
+    typedef Pool Database;
+}
+namespace Appstream = AppStream;
+#else
 #include <AppstreamQt/database.h>
+#endif
 
 class AppstreamReviews;
 class AppPackageKitResource;
